@@ -11,7 +11,7 @@ use Module::Build;
 
 my $builder = Module::Build->new(
     module_name       => '<%= $c->module %>',
-    license           => 'perl',
+    license           => '<%= $c->config('license') || 'perl' %>',
     dist_author       => '<%= $c->config('author') %> <<%= $c->config('email') %>>',
     dist_version_from => '<%= $c->mainfile %>',
     requires => {
@@ -20,6 +20,9 @@ my $builder = Module::Build->new(
         'Test::More'          => '0.47',
         'Test::UseAllModules' => '0.10',
     },
+    resources => {
+        repository => '<%= $c->repository %>',
+    },
 );
 
 $builder->create_build_script;
